==> xcat-2.14.1.lenovo2_confluent-2.0.2-sles12.tar.bz2: opt/xcat/lib/perl/xCAT/Version.pm <==
#!/usr/bin/env perl
# IBM(c) 2007 EPL license http://www.eclipse.org/legal/epl-v10.html
package xCAT::Version;

BEGIN
{
    $::XCATROOT = $ENV{'XCATROOT'} ? $ENV{'XCATROOT'} : '/opt/xcat';
}

# if AIX - make sure we include perl 5.8.2 in INC path.
#       Needed to find perl dependencies shipped in deps tarball.
if ($^O =~ /^aix/i) {
    unshift(@INC, qw(/usr/opt/perl5/lib/5.8.2/aix-thread-multi /usr/opt/perl5/lib/5.8.2 /usr/opt/perl5/lib/site_perl/5.8.2/aix-thread-multi /usr/opt/perl5/lib/site_perl/5.8.2));
}

use lib "$::XCATROOT/lib/perl";

# do not put a use or require for  xCAT::Table here. Add to each new routine
# needing it to avoid reprocessing of user tables ( ExtTab.pm) for each command call
use strict;

#-------------------------------------------------------------------------------

=head3   Version 
    Arguments:
        Optional 'short' string to request only the version;
    Returns:
       xcat Version number 
    Globals:
        none
    Error:
        none
    Example:
         $version=xCAT::Version->Version();
    Comments:
        none
=cut

#-------------------------------------------------------------------------------
sub Version
{

    #The following tags tells the build script where to append build info
    my $version = shift;
    if ($version eq 'short')
    {
        $version = ''    . '2.14.1.lenovo2' ;
    }
    else
    {
        $version = 'Version '    . '2.14.1.lenovo2' . ' (git commit 06d7097f42eca03db70c9eb93b8abeaf8ca1c2be, built Mon Aug 20 08:56:35 EDT 2018)' ;
    }
    return $version;

}

1;

==> xcat-2.14.5.lenovo2_confluent-2.2.0-sles12.tar.bz2: opt/xcat/lib/perl/xCAT/Version.pm <==
#!/usr/bin/env perl
# IBM(c) 2007 EPL license http://www.eclipse.org/legal/epl-v10.html
package xCAT::Version;

BEGIN
{
    $::XCATROOT = $ENV{'XCATROOT'} ? $ENV{'XCATROOT'} : '/opt/xcat';
}

# if AIX - make sure we include perl 5.8.2 in INC path.
#       Needed to find perl dependencies shipped in deps tarball.
if ($^O =~ /^aix/i) {
    unshift(@INC, qw(/usr/opt/perl5/lib/5.8.2/aix-thread-multi /usr/opt/perl5/lib/5.8.2 /usr/opt/perl5/lib/site_perl/5.8.2/aix-thread-multi /usr/opt/perl5/lib/site_perl/5.8.2));
}

use lib "$::XCATROOT/lib/perl";

# do not put a use or require for  xCAT::Table here. Add to each new routine
# needing it to avoid reprocessing of user tables ( ExtTab.pm) for each command call
use strict;

#-------------------------------------------------------------------------------

=head3   Version
    Arguments:
        Optional 'short' string to request only the version;
    Returns:
       xcat Version number
    Globals:
        none
    Error:
        none
    Example:
         $version=xCAT::Version->Version();
    Comments:
        none
=cut

#-------------------------------------------------------------------------------
sub Version
{

    #The following tags tells the build script where to append build info
    my $version = shift;
    if ($version eq 'short')
    {
        $version = ''    . '2.14.5.lenovo2' ;
    }
    else
    {
        $version = 'Version '    . '2.14.5.lenovo2' . ' (git commit 06d7097f42eca03db70c9eb93b8abeaf8ca1c2be, built Tue Apr 16 16:10:03 EDT 2019)' ;
    }
    return $version;

}

1;
